# CLAMS sdk for python 

**NOTE** that this project is in pre-alpha and being actively developed. Nothing is guaranteed to reliably work for the moment and developer need to be very careful when using APIs implemented here. Please use [the issue track](../../issues) to report bugs and malfunctions, or send pull requests for even more contribution. 

## CLAMS project
[CLAMS project](https://www.clams.ai) aims at free and open-source software platform for computational analysis and metadata generation applications for multimedia material. 

## installation: 
Package `clams-python` is distributed via the official pypi. Users are supposed to pip-install to get latest release. 
```
pip install clams-python
```
This will install a packge `clams` to local python 

## APIs


`clams.ClamsApp` : an abstract class for clams apps
